<?php

/*----------------------------------------------------------------------------------|  simontech.me  |----/

				Award Manager by SimonTech Development

/-------------------------------------------------------------------------------------------------------/



	@version		1.0.7

	@build			8th June, 2019

	@created		19th April, 2019

	@package		Award Manager

	@subpackage		nominees.php

	@author			SimonTech <https://simontech.me>

	@copyright		Copyright (C) 2019 SimonTech Development. All Rights Reserved

	@license		GNU/GPL Version 2 or later - http://www.gnu.org/licenses/gpl-2.0.html

  ____  _____  _____  __  __  __      __       ___  _____  __  __  ____  _____  _  _  ____  _  _  ____

 (_  _)(  _  )(  _  )(  \/  )(  )    /__\     / __)(  _  )(  \/  )(  _ \(  _  )( \( )( ___)( \( )(_  _)

.-_)(   )(_)(  )(_)(  )    (  )(__  /(__)\   ( (__  )(_)(  )    (  )___/ )(_)(  )  (  )__)  )  (   )(

\____) (_____)(_____)(_/\/\_)(____)(__)(__)   \___)(_____)(_/\/\_)(__)  (_____)(_)\_)(____)(_)\_) (__)



/------------------------------------------------------------------------------------------------------*/



// No direct access to this file

defined('_JEXEC') or die('Restricted access');



/**

 * Nominees Model

 */

class Award_managerModelNominees extends JModelList

{

	public function __construct($config = array())

	{

		if (empty($config['filter_fields']))

        {

			$config['filter_fields'] = array(

				'a.id','id',

				'a.published','published',

				'a.ordering','ordering',

				'a.created_by','created_by',

				'a.modified_by','modified_by',

				'a.type','type',

				'a.catid','category',

				'a.firstname','firstname'

			);

		}



		parent::__construct($config);

	}



	/**

	 * Method to auto-populate the model state.

	 *

	 * @return  void

	 */

	protected function populateState($ordering = null, $direction = null)

	{

		$app = JFactory::getApplication();



		// Adjust the context to support modal layouts.

		if ($layout = $app->input->get('layout'))

		{

			$this->context .= '.' . $layout;

		}

		$type = $this->getUserStateFromRequest($this->context . '.filter.type', 'filter_type');

		$this->setState('filter.type', $type);



		$category = $this->getUserStateFromRequest($this->context . '.filter.category', 'filter_category');

		$this->setState('filter.category', $category);



		$firstname = $this->getUserStateFromRequest($this->context . '.filter.firstname', 'filter_firstname');

		$this->setState('filter.firstname', $firstname);



		$sorting = $this->getUserStateFromRequest($this->context . '.filter.sorting', 'filter_sorting', 0, 'int');

		$this->setState('filter.sorting', $sorting);



		$access = $this->getUserStateFromRequest($this->context . '.filter.access', 'filter_access', 0, 'int');

		$this->setState('filter.access', $access);



		$search = $this->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');

		$this->setState('filter.search', $search);



		$published = $this->getUserStateFromRequest($this->context . '.filter.published', 'filter_published', '');

		$this->setState('filter.published', $published);



		$created_by = $this->getUserStateFromRequest($this->context . '.filter.created_by', 'filter_created_by', '');

		$this->setState('filter.created_by', $created_by);



		$created = $this->getUserStateFromRequest($this->context . '.filter.created', 'filter_created');

		$this->setState('filter.created', $created);



		// List state information.

		parent::populateState($ordering, $direction);

	}



	/**

	 * Method to get an array of data items.

	 *

	 * @return  mixed  An array of data items on success, false on failure.

	 */

	public function getItems()

	{

		// load parent items

		$items = parent::getItems();



		// set values to display correctly.

		if (Award_managerHelper::checkArray($items))

		{

			foreach ($items as $nr => &$item)

			{

				$access = (JFactory::getUser()->authorise('nominee.access', 'com_award_manager.nominee.' . (int) $item->id) && JFactory::getUser()->authorise('nominee.access', 'com_award_manager'));

				if (!$access)

				{

					unset($items[$nr]);

					continue;

				}



			}

		}



		// return items

		return $items;

	}



	/**

	 * Method to build an SQL query to load the list data.

	 *

	 * @return	string	An SQL query

	 */

	protected function getListQuery()

	{

		// Get the user object.

		$user = JFactory::getUser();

		// Create a new query object.

		$db = JFactory::getDBO();

		$query = $db->getQuery(true);



		// Select some fields

		$query->select('a.*');



		// From the award_manager_item table

		$query->from($db->quoteName('#__award_manager_nominee', 'a'));



		// Filter by published state

		$published = $this->getState('filter.published');

		if (is_numeric($published))

		{

			$query->where('a.published = ' . (int) $published);

		}

		elseif ($published === '')

		{

			$query->where('(a.published = 0 OR a.published = 1)');

		}



		// Join over the asset groups.

		$query->select('ag.title AS access_level');

		$query->join('LEFT', '#__viewlevels AS ag ON ag.id = a.access');

		// Filter by access level.

		if ($access = $this->getState('filter.access'))

		{

			$query->where('a.access = ' . (int) $access);

		}

		// Implement View Level Access

		if (!$user->authorise('core.options', 'com_award_manager'))

		{

			$groups = implode(',', $user->getAuthorisedViewLevels());

			$query->where('a.access IN (' . $groups . ')');

		}

		// Filter by search.

		$search = $this->getState('filter.search');

		if (!empty($search))

		{

			if (stripos($search, 'id:') === 0)

			{

				$query->where('a.id = ' . (int) substr($search, 3));

			}

			else

			{

				$search = $db->quote('%' . $db->escape($search) . '%');

				$query->where('(a.firstname LIKE '.$search.' OR a.title LIKE '.$search.' OR a.lastname LIKE '.$search.' OR a.parentemail LIKE '.$search.' OR a.agentphone LIKE '.$search.' OR a.projage LIKE '.$search.' OR a.telnumber LIKE '.$search.' OR a.parent LIKE '.$search.' OR a.cntry LIKE '.$search.' OR a.cityst LIKE '.$search.' OR a.character LIKE '.$search.' OR a.roletype LIKE '.$search.' OR a.airdate LIKE '.$search.' OR a.distribco LIKE '.$search.' OR a.info LIKE '.$search.' OR a.agentadd LIKE '.$search.')');

			}

		}



		// Join over the categories.

		$query->select($db->quoteName(

			array('c.title','c.path'),

			array('category_title','category_path')))

			->join('LEFT', $db->quoteName('#__categories', 'c') . ' ON c.id = a.catid');



		// Filter by Firstname.

		if ($firstname = $this->getState('filter.firstname'))

		{

			$query->where('a.firstname = ' . $db->quote($db->escape($firstname)));

		}

		// Filter by Type.

		if ($type = $this->getState('filter.type'))

		{

			$query->where('a.type = ' . $db->quote($db->escape($type)));

		}



		// Filter by Category.

		if ($category = $this->getState('filter.category'))

		{

			$query->where('a.catid = ' . $db->quote($db->escape($category)));

		}



		// Add the list ordering clause.

		$orderCol = $this->state->get('list.ordering', 'a.id');

		$orderDirn = $this->state->get('list.direction', 'asc');

		if ($orderCol != '')

		{

			$query->order($db->escape($orderCol . ' ' . $orderDirn));

		}



		return $query;

	}



	/**

	 * Method to get list export data.

	 *

	 * @return mixed  An array of data items on success, false on failure.

	 */

	public function getExportData($pks)

	{

		// setup the query

		if (Award_managerHelper::checkArray($pks))

		{

			// Set a value to know this is exporting method.

			$_export = true;

			// Get the user object.

			$user = JFactory::getUser();

			// Create a new query object.

			$db = JFactory::getDBO();

			$query = $db->getQuery(true);



			// Select some fields

			$query->select('a.*');



			// From the award_manager_nominee table

			$query->from($db->quoteName('#__award_manager_nominee', 'a'));

			$query->where('a.id IN (' . implode(',',$pks) . ')');

			// Implement View Level Access

			if (!$user->authorise('core.options', 'com_award_manager'))

			{

				$groups = implode(',', $user->getAuthorisedViewLevels());

				$query->where('a.access IN (' . $groups . ')');

			}



			// Order the results by ordering

			$query->order('a.ordering  ASC');



			// Load the items

			$db->setQuery($query);

			$db->execute();

			if ($db->getNumRows())

			{

				$items = $db->loadObjectList();



				// Get the basic encryption key.

				$basickey = Award_managerHelper::getCryptKey('basic');

				// Get the encryption object.

				$basic = new FOFEncryptAes($basickey);



				// set values to display correctly.

				if (Award_managerHelper::checkArray($items))

				{

					foreach ($items as $nr => &$item)

					{

						$access = (JFactory::getUser()->authorise('nominee.access', 'com_award_manager.nominee.' . (int) $item->id) && JFactory::getUser()->authorise('nominee.access', 'com_award_manager'));

						if (!$access)

						{

							unset($items[$nr]);

							continue;

						}



						if ($basickey && !is_numeric($item->lifestyle_image) && $item->lifestyle_image === base64_encode(base64_decode($item->lifestyle_image, true)))

						{

							// decrypt lifestyle_image

							$item->lifestyle_image = $basic->decryptString($item->lifestyle_image);

						}

						if ($basickey && !is_numeric($item->headshot_image) && $item->headshot_image === base64_encode(base64_decode($item->headshot_image, true)))

						{

							// decrypt headshot_image

							$item->headshot_image = $basic->decryptString($item->headshot_image);

						}

						// unset the values we don't want exported.

						unset($item->asset_id);

						unset($item->checked_out);

						unset($item->checked_out_time);

					}

				}

				// Add headers to items array.

				$headers = $this->getExImPortHeaders();

				if (Award_managerHelper::checkObject($headers))

				{

					array_unshift($items,$headers);

				}

				return $items;

			}

		}

		return false;

	}



	/**

	* Method to get header.

	*

	* @return mixed  An array of data items on success, false on failure.

	*/

	public function getExImPortHeaders()

	{

		// Get a db connection.

		$db = JFactory::getDbo();

		// get the columns

		$columns = $db->getTableColumns("#__award_manager_nominee");

		if (Award_managerHelper::checkArray($columns))

		{

			// remove the headers you don't import/export.

			unset($columns['asset_id']);

			unset($columns['checked_out']);

			unset($columns['checked_out_time']);

			$headers = new stdClass();

			foreach ($columns as $column => $type)

			{

				$headers->{$column} = $column;

			}

			return $headers;

		}

		return false;

	}



	/**

	 * Method to get a store id based on model configuration state.

	 *

	 * @return  string  A store id.

	 *

	 */

	protected function getStoreId($id = '')

	{

		// Compile the store id.

		$id .= ':' . $this->getState('filter.id');

		$id .= ':' . $this->getState('filter.search');

		$id .= ':' . $this->getState('filter.published');

		$id .= ':' . $this->getState('filter.ordering');

		$id .= ':' . $this->getState('filter.created_by');

		$id .= ':' . $this->getState('filter.modified_by');

		$id .= ':' . $this->getState('filter.type');

		$id .= ':' . $this->getState('filter.firstname');



		return parent::getStoreId($id);

	}

}

